;; Generated package description from perl-doc.el  -*- no-byte-compile: t -*-
(define-package "perl-doc" "0.4.0.20220927.164548" "Read Perl documentation" '((emacs "27")) :commit "7490782dd1cdfe2e49f8da17033c27c2e5a09317" :authors '(("Harald Jörg" . "haj@posteo.de")) :maintainer '("Harald Jörg" . "haj@posteo.de") :keywords '("languages") :url "https://github.com/HaraldJoerg/emacs-perl-doc")
